==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregando pré-visualização...",
    "Admin" : "Administrador",
    "Saved" : "Salva",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Error uploading the file" : "Erro ao carregar o arquivo",
    "Name cannot be empty" : "O nome não pode ficar em branco",
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given legal notice address is not a valid URL" : "O endereço do aviso legal não é uma URL válida",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "Dark theme with high contrast mode" : "Tema escuro com modo de alto contraste",
    "Enable dark high contrast mode" : "Ative o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semelhante ao modo de alto contraste, mas com cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Um tema escuro para aliviar seus olhos, reduzindo a luminosidade e o brilho gerais.",
    "System default theme" : "Tema padrão do sistema",
    "Enable the system default" : "Ativar o padrão do sistema",
    "Using the default system appearance." : "Usando a aparência padrão do sistema.",
    "Dyslexia font" : "Fonte de dislexia",
    "Enable dyslexia font" : "Ativar fonte dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é um tipo de letra/fonte grátis concebida para atenuar alguns dos erros comuns de leitura causados pela dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Ativar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "O modo de alto contraste facilita a navegação. A qualidade visual será reduzida, mas a clareza será aumentada.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Ative o tema de luz padrão",
    "The default light appearance." : "A aparência de luz padrão.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Keyboard shortcuts" : "Atalhos do teclado",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
    "Disable all keyboard shortcuts" : "Desabilitar todos os atalhos de teclado",
    "Background" : "Fundo",
    "Set a custom background" : "Defina um plano de fundo personalizado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
    "Pick from Files" : "Escolher de Arquivos",
    "Default image" : "Imagem padrão",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}",
    "Theme selection is enforced" : "A seleção do tema é aplicada",
    "Open documentation" : "Abrir documentação",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Name" : "Nome",
    "Reset to default" : "Redefinir para o padrão",
    "Web link" : "Link web",
    "https://…" : "https://...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Remove background image" : "Excluir a imagem de fundo",
    "Advanced options" : "Opções avançadas",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given legal notice address is not a valid URL" : "O endereço do aviso legal não é uma URL válida",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "Disable-user-theming should be true or false" : "Desabilitar-tema-usuário deve ser verdadeiro ou falso",
    "Saved" : "Salva",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "Cleanup old theming cache" : "Limpar cache de temas antigos",
    "Failed to delete folder: \"%1$s\", error: %2$s" : "Falha ao excluir a pasta:\"%1$s\", erro: %2$s",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "Dark theme with high contrast mode" : "Tema escuro com modo de alto contraste",
    "Enable dark high contrast mode" : "Ative o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semelhante ao modo de alto contraste, mas com cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Um tema escuro para aliviar seus olhos, reduzindo a luminosidade e o brilho gerais.",
    "System default theme" : "Tema padrão do sistema",
    "Enable the system default" : "Ativar o padrão do sistema",
    "Using the default system appearance." : "Usando a aparência padrão do sistema.",
    "Dyslexia font" : "Fonte de dislexia",
    "Enable dyslexia font" : "Ativar fonte dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é um tipo de letra/fonte grátis concebida para atenuar alguns dos erros comuns de leitura causados pela dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Ativar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "O modo de alto contraste facilita a navegação. A qualidade visual será reduzida, mas a clareza será aumentada.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Ative o tema de luz padrão",
    "The default light appearance." : "A aparência de luz padrão.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Advanced options" : "Opções avançadas",
    "Name" : "Nome",
    "Web link" : "Link web",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Background and login image" : "Plano de fundo e imagem de login",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "User settings" : "Configurações de usuário",
    "Disable user theming" : "Desabilitar temas do usuário",
    "Keyboard shortcuts" : "Atalhos do teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
    "Disable all keyboard shortcuts" : "Desabilitar todos os atalhos de teclado",
    "Background" : "Fundo",
    "Customization has been disabled by your administrator" : "A personalização foi desativada pelo seu administrador",
    "Set a custom background" : "Defina um plano de fundo personalizado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
    "Pick from Files" : "Escolher de Arquivos",
    "Default image" : "Imagem padrão",
    "Custom color" : "Cor personalizada",
    "Plain background" : "Fundo simples",
    "Insert from {productName}" : "Inserir de {productName}",
    "Theme selection is enforced" : "A seleção do tema é aplicada",
    "Reset to default" : "Redefinir para o padrão",
    "Upload" : "Enviar",
    "Remove background image" : "Excluir a imagem de fundo",
    "Loading preview…" : "Carregando pré-visualização...",
    "Admin" : "Administrador",
    "Name cannot be empty" : "O nome não pode ficar em branco",
    "Open documentation" : "Abrir documentação",
    "https://…" : "https://...",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados.",
    "Error uploading the file" : "Erro ao carregar o arquivo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
